fix, work
[lcr.git] / mISDN.h
diff --git a/mISDN.h b/mISDN.h
index 1798b88..32ed6d8 100644 (file)
--- a/mISDN.h
+++ b/mISDN.h
@@ -1,6 +1,6 @@
 /*****************************************************************************\
 **                                                                           **
-** PBX4Linux                                                                 **
+** Linux Call Router                                                         **
 **                                                                           **
 **---------------------------------------------------------------------------**
 ** Copyright: Andreas Eversberg                                              **
@@ -9,20 +9,6 @@
 **                                                                           **
 \*****************************************************************************/ 
 
-enum {
-       B_STATE_IDLE,
-       B_STATE_ACTIVATING,
-       B_STATE_ACTIVE,
-       B_STATE_DEACTIVATING,
-};
-
-enum {
-       B_EVENT_ACTIVATE,
-       B_EVENT_ACTIVATED,
-       B_EVENT_DEACTIVATE,
-       B_EVENT_DEACTIVATED,
-};
-
 #define FROMUP_BUFFER_SIZE 1024
 #define FROMUP_BUFFER_MASK 1023
 
@@ -46,18 +32,21 @@ struct mISDNport {
        int use; /* counts the number of port that uses this port */
        int ntmode; /* is TRUE if port is nt mode */
        int pri; /* is TRUE if port is a primary rate interface */
-       int is_tones; /* TRUE if tones are sent outside connect state */
-       int is_earlyb; /* TRUE if tones are received outside connect state */
+       int tones; /* TRUE if tones are sent outside connect state */
+       int earlyb; /* TRUE if tones are received outside connect state */
        int upper_id; /* id to transfer data down */
        int lower_id; /* id to transfer data up */
        int d_stid;
        int b_num; /* number of bchannels */
        int b_reserved; /* number of bchannels reserved or in use */
-       class PmISDN *b_port[128]; /* maximum number of ports shall be 128 due to S0 / E1 / special E1 */
+       class PmISDN *b_port[128]; /* bchannel assigned to port object */
        int b_stid[128];
-       int b_addr[128];
-       int b_state[128]; /* state 0 = IDLE */
+       unsigned long b_addr[128];
+       int b_state[128]; /* statemachine, 0 = IDLE */
+       unsigned long b_remote_id[128]; /* the socket currently exported */
+       unsigned long b_remote_ref[128]; /* the ref currently exported */
        int procids[128]; /* keep track of free ids */
+       int locally; /* local causes are sent as local causes not remote */
        msg_queue_t downqueue;          /* l4->l3 */
 };
 extern mISDNport *mISDNport_first;
@@ -78,8 +67,10 @@ calls with no bchannel (call waiting, call on hold).
 
 
 /* mISDN none-object functions */
+int mISDN_initialize(void);
+void mISDN_deinitialize(void);
 void mISDN_port_info(void);
-struct mISDNport *mISDNport_open(int port, int ptp, int ptmp);
+struct mISDNport *mISDNport_open(int port, int ptp, int ptmp, struct interface *interface);
 void mISDNport_close_all(void);
 void mISDNport_close(struct mISDNport *mISDNport);
 void mISDN_port_reorder(void);
@@ -94,6 +85,7 @@ int stack2manager_te(struct mISDNport *mISDNport, msg_t *msg);
 void chan_trace_header(struct mISDNport *mISDNport, class PmISDN *port, char *msgtext, int direction);
 void l1l2l3_trace_header(struct mISDNport *mISDNport, class PmISDN *port, unsigned long prim, int direction);
 void bchannel_event(struct mISDNport *mISDNport, int i, int event);
+void message_bchannel_from_join(class JoinRemote *joinremote, int type, unsigned long addr);
 
 
 /* mISDN port classes */
@@ -117,11 +109,14 @@ class PmISDN : public Port
 //     int p_m_nodata;                         /* all parties within a conf are isdn ports, so pure bridging is possible */
        int p_m_txdata;                         /* get what we transmit */
        int p_m_dtmf;                           /* dtmf decoding is enabled */
-       int p_m_calldata;                       /* the call requires data due to no briging capability */
-
-       int p_m_fromup_buffer_readp;            /* buffer for audio from remote endpoint */
-       int p_m_fromup_buffer_writep;
-       unsigned char p_m_fromup_buffer[FROMUP_BUFFER_SIZE];
+       int p_m_joindata;                       /* the call requires data due to no briging capability */
+
+       int p_m_load;                           /* current data in dsp tx buffer */
+       unsigned long p_m_last_tv_sec;          /* time stamp of last handler call, (to sync audio data */
+       unsigned long p_m_last_tv_msec;
+//     int p_m_fromup_buffer_readp;            /* buffer for audio from remote endpoint */
+//     int p_m_fromup_buffer_writep;
+//     unsigned char p_m_fromup_buffer[FROMUP_BUFFER_SIZE];
        void txfromup(unsigned char *data, int length);
 
        int p_m_crypt;                          /* encryption is enabled */
@@ -146,12 +141,14 @@ class PmISDN : public Port
        int p_m_b_channel;                      /* number 1,2 1..15,17... */
        int p_m_b_exclusive;                    /* if bchannel is exclusive */
        int p_m_b_reserve;                      /* set if channel is reserved */
-       long long p_m_jittercheck;              /* time of audio data */
-       long long p_m_jitterdropped;            /* number of bytes dropped */
+//     long long p_m_jittercheck;              /* time of audio data */
+//     long long p_m_jitterdropped;            /* number of bytes dropped */
        int p_m_delete;                         /* true if obj. must del. */
        int p_m_hold;                           /* if port is on hold */
        unsigned long p_m_timeout;              /* timeout of timers */
        time_t p_m_timer;                       /* start of timer */
+       unsigned char p_m_remote_ref;           /* join to export bchannel to */
+       unsigned char p_m_remote_id;            /* sock to export bchannel to */
 
        int seize_bchannel(int channel, int exclusive); /* requests / reserves / links bchannels, but does not open it! */
        void drop_bchannel(void);